#====================================================================
# Processes queue size vs time for a given router queue.  Output queue
# size is in bits; time is in seconds.
# 
# Reads ns trace data (for a specific queue) from standard input and
# outputs to standard output.
#====================================================================


import sys


# Read trace data from the standard input.
# Each field in each line is separated by a space.
#  The 1st field is an event which was recorded.
#  The 2nd field is the time at which it was recorded.
#  The 6th field is the packet size in bytes.
# All other fields are irrelevant.
trace_data = sys.stdin


# Store event data from input trace data.
events = []
for line in trace_data:
	fields = [field.strip() for field in line.split()]
	time = float(fields[1])
	event = fields[0]
	pkt_size = float(fields[5])
	events.append((time, event, pkt_size))
trace_data.close()


if len(events) > 0:

	# For each event in the trace data, adjust the queue size according to 
	#  the event.
	queue_size = 0 # bits.	
	for time, event, pkt_size in events:
		print str(time) + " " + str(queue_size)
		if event == "+": # A packet was enqueued.
			queue_size += pkt_size 
		elif event == "-": # A packet was dequeued.
			queue_size -= pkt_size 
		elif event == "d": # The packet was dropped from the queue.
			queue_size -= pkt_size 
		print str(time) + " " + str(queue_size)
else:
	print "0 0"
