import sys


# Normalization factor for throughput results.
normal = 1 # Default value- no change.
if (len(sys.argv) > 1):
	normal = float(sys.argv[1]) # Optional 1st command-line argument.

# Interval, in seconds, at which to record throughput data.
interval = 0.001 # Default value.
if (len(sys.argv) > 2): 
	interval = float(sys.argv[2]) # Optional 2nd command-line argument.


# Read trace data from the standard input.
# Each field in each line is separated by a space.
#  The 1st field is an event which was recorded.
#  The 2nd field is the time at which it was recorded.
#  The 6th field is the packet size in bytes.
# All other fields are irrelevant.
trace_data = sys.stdin


# Store event data from input trace data.
events = []
for line in trace_data:
	fields = [field.strip() for field in line.split()]
	time = float(fields[1])
	event = fields[0]
	pkt_size = float(fields[5])
	events.append((time, event, pkt_size))
trace_data.close()


if len(events) > 0:
	throughput = [] # Relates time to throughput at that time.
	start_time = events[0][0] # seconds.
	bits = 0 # data received at the end of the link.
	
	for time, event, pkt_size in events:
		# If an interval of time has passed, record the current
		#  throughput then reset the start time and data counter.
		if time > start_time + interval:
			print str(start_time) + " " + str(float(bits)/float(interval)/float(normal))
			start_time += interval
			bits = 0

		# Adjust the throughput when data is received.
		if event == "r": # The packet was received at the other end of the link.
			bits += pkt_size * 8
		else:
			pass


else:
	print "0 0"
